@@ -1,6 +1,6 @@
 package XML::MyXML;
 {
-  $XML::MyXML::VERSION = '0.0988';
+  $XML::MyXML::VERSION = '0.0989';
 }
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
 
@@ -91,7 +91,7 @@ sub xml_to_object {
 	my $soft = $flags->{'soft'}; # soft = 'don't die if can't parse, just return undef'
 
 	if ($flags->{'file'}) {
-		open my $fh, $xml or do { confess "Error: The file '$xml' could not be opened for reading." unless $soft; return undef; };
+		open my $fh, '<', $xml or do { confess "Error: The file '$xml' could not be opened for reading." unless $soft; return undef; };
 		$xml = join '', <$fh>;
 		close $fh;
 	}
@@ -300,7 +300,7 @@ sub simple_to_xml {
 	if ($flags->{'utf8'}) { Encode::_utf8_on($xml); }
 
 	if (defined $flags->{'save'}) {
-		open my $fh, ">$flags->{'save'}" or confess "Error: Couldn't open file '$flags->{'save'}' for writing";
+		open my $fh, '>', $flags->{'save'} or confess "Error: Couldn't open file '$flags->{'save'}' for writing";
 		if ($flags->{'utf8'}) { binmode $fh, ':utf8'; }
 		print $fh $xml;
 		close $fh;
@@ -475,7 +475,7 @@ sub check_xml {
 
 package XML::MyXML::Object;
 {
-  $XML::MyXML::Object::VERSION = '0.0988';
+  $XML::MyXML::Object::VERSION = '0.0989';
 }
 
 use Carp;
@@ -605,7 +605,7 @@ sub to_xml {
 	$xml = $decl . $xml;
 	if ($flags->{'utf8'}) { Encode::_utf8_on($xml); }
 	if (defined $flags->{'save'}) {
-		open my $fh, ">$flags->{'save'}" or confess "Error: Couldn't open file '$flags->{'save'}' for writing";
+		open my $fh, '>', $flags->{'save'} or confess "Error: Couldn't open file '$flags->{'save'}' for writing";
 		if ($flags->{'utf8'}) { binmode $fh, ':utf8'; }
 		print $fh $xml;
 		close $fh;
@@ -665,7 +665,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.0988
+version 0.0989
 
 =head1 SYNOPSIS
 
